@@ -31,6 +31,7 @@ from buildbot.process.results import RETRY
 from buildbot.util import bytes2unicode
 from buildbot.util import epoch2datetime
 from buildbot.util import service as util_service
+from buildbot.util.render_description import render_description
 
 
 def enforceChosenWorker(bldr, workerforbuilder, breq):
@@ -79,15 +80,24 @@ class Builder(util_service.ReconfigurableServiceMixin,
         # Tracks config version for locks
         self.config_version = None
 
-    @defer.inlineCallbacks
-    def reconfigServiceWithBuildbotConfig(self, new_config):
-        # find this builder in the config
+    def _find_builder_config_by_name(self, new_config):
         for builder_config in new_config.builders:
             if builder_config.name == self.name:
-                found_config = True
-                break
-        assert found_config, "no config found for builder '{}'".format(self.name)
+                return builder_config
+        raise AssertionError(f"no config found for builder '{self.name}'")
 
+    @defer.inlineCallbacks
+    def find_project_id(self, project):
+        if project is None:
+            return project
+        projectid = yield self.master.data.updates.find_project_id(project)
+        if projectid is None:
+            log.msg(f"{self} could not find project ID for project name {project}")
+        return projectid
+
+    @defer.inlineCallbacks
+    def reconfigServiceWithBuildbotConfig(self, new_config):
+        builder_config = self._find_builder_config_by_name(new_config)
         old_config = self.config
         self.config = builder_config
         self.config_version = self.master.config_version
@@ -98,9 +108,19 @@ class Builder(util_service.ReconfigurableServiceMixin,
         builderid = yield self.getBuilderId()
 
         if self._has_updated_config_info(old_config, builder_config):
-            yield self.master.data.updates.updateBuilderInfo(builderid,
-                                                             builder_config.description,
-                                                             builder_config.tags)
+            projectid = yield self.find_project_id(builder_config.project)
+
+            yield self.master.data.updates.updateBuilderInfo(
+                builderid,
+                builder_config.description,
+                builder_config.description_format,
+                render_description(
+                    builder_config.description,
+                    builder_config.description_format
+                ),
+                projectid,
+                builder_config.tags
+            )
 
         # if we have any workers attached which are no longer configured,
         # drop them.
@@ -113,12 +133,16 @@ class Builder(util_service.ReconfigurableServiceMixin,
             return True
         if old_config.description != new_config.description:
             return True
+        if old_config.description_format != new_config.description_format:
+            return True
+        if old_config.project != new_config.project:
+            return True
         if old_config.tags != new_config.tags:
             return True
         return False
 
     def __repr__(self):
-        return "<Builder '%r' at %d>" % (self.name, id(self))
+        return f"<Builder '{repr(self.name)}' at {id(self)}>"
 
     def getBuilderIdForName(self, name):
         # buildbot.config should ensure this is already unicode, but it doesn't
@@ -173,6 +197,22 @@ class Builder(util_service.ReconfigurableServiceMixin,
         else:
             return None
 
+    @defer.inlineCallbacks
+    def get_highest_priority(self):
+        """Returns the priority of the highest priority unclaimed build request
+        for this builder, or None if there are no build requests.
+
+        @returns: priority or None, via Deferred
+        """
+        bldrid = yield self.getBuilderId()
+        unclaimed = yield self.master.data.get(
+            ('builders', bldrid, 'buildrequests'),
+            [resultspec.Filter('claimed', 'eq', [False])],
+            order=['-priority'], limit=1)
+        if unclaimed:
+            return unclaimed[0]['priority']
+        return None
+
     def getBuild(self, number):
         for b in self.building:
             if b.number == number:
@@ -238,16 +278,19 @@ class Builder(util_service.ReconfigurableServiceMixin,
             log.err(e, 'worker failed to attach')
             return None
 
-    def detached(self, worker):
-        """This is called when the connection to the bot is lost."""
+    def _find_wfb_by_worker(self, worker):
         for wfb in self.attaching_workers + self.workers:
             if wfb.worker == worker:
-                break
-        else:
-            log.msg(("WEIRD: Builder.detached({}) ({})"
-                     " not in attaching_workers({})"
-                     " or workers({})").format(worker, worker.workername, self.attaching_workers,
-                                               self.workers))
+                return wfb
+        return None
+
+    def detached(self, worker):
+        """This is called when the connection to the bot is lost."""
+        wfb = self._find_wfb_by_worker(worker)
+        if wfb is None:
+            log.msg(f"WEIRD: Builder.detached({worker}) ({worker.workername})"
+                    f" not in attaching_workers({self.attaching_workers})"
+                    f" or workers({self.workers})")
             return
 
         if wfb in self.attaching_workers:
@@ -320,7 +363,7 @@ class Builder(util_service.ReconfigurableServiceMixin,
         Build.setupPropertiesKnownBeforeBuildStarts(
             props, build.requests, build.builder, workerforbuilder)
 
-        log.msg("starting build {} using worker {}".format(build, workerforbuilder))
+        log.msg(f"starting build {build} using worker {workerforbuilder}")
 
         # set up locks
         locks = yield build.render(self.config.locks)
