@@ -57,7 +57,7 @@ class Darcs(Source):
             if self.method is None:
                 self.method = 'copy'
             elif self.method not in self.possible_methods:
-                errors.append("Invalid method for mode == {self.mode}")
+                errors.append(f"Invalid method for mode == {self.mode}")
 
         if repourl is None:
             errors.append("you must provide repourl")
@@ -157,7 +157,7 @@ class Darcs(Source):
     def _checkout(self):
 
         if self.retry:
-            abandonOnFailure = (self.retry[1] <= 0)
+            abandonOnFailure = self.retry[1] <= 0
         else:
             abandonOnFailure = True
 
