@@ -14,10 +14,13 @@
 # Copyright Buildbot Team Members
 
 
+import types
+
 from twisted.internet import defer
 
 from buildbot.db import model
 from buildbot.test.fake import fakemaster
+from buildbot.test.reactor import TestReactorMixin
 from buildbot.test.util import db
 
 
@@ -25,7 +28,7 @@ class FakeDBConnector:
     pass
 
 
-class ConnectorComponentMixin(db.RealDatabaseMixin):
+class ConnectorComponentMixin(TestReactorMixin, db.RealDatabaseMixin):
 
     """
     Implements a mock DBConnector object, replete with a thread pool and a DB
@@ -39,8 +42,10 @@ class ConnectorComponentMixin(db.RealDatabaseMixin):
     """
 
     @defer.inlineCallbacks
-    def setUpConnectorComponent(self, table_names=None, basedir='basedir'):
+    def setUpConnectorComponent(self, table_names=None, basedir='basedir', dialect_name='sqlite'):
         """Set up C{self.db}, using the given db_url and basedir."""
+        self.setup_test_reactor()
+
         if table_names is None:
             table_names = []
 
@@ -48,15 +53,27 @@ class ConnectorComponentMixin(db.RealDatabaseMixin):
 
         self.db = FakeDBConnector()
         self.db.pool = self.db_pool
-        self.db.master = fakemaster.make_master()
+        self.db.master = fakemaster.make_master(self)
         self.db.model = model.Model(self.db)
+        self.db._engine = types.SimpleNamespace(dialect=types.SimpleNamespace(name=dialect_name))
 
     @defer.inlineCallbacks
     def tearDownConnectorComponent(self):
         yield self.tearDownRealDatabase()
-
-        self.db_pool.shutdown()
         # break some reference loops, just for fun
         del self.db.pool
         del self.db.model
         del self.db
+
+
+class FakeConnectorComponentMixin(TestReactorMixin):
+    # Just like ConnectorComponentMixin, but for working with fake database
+
+    def setUpConnectorComponent(self):
+        self.setup_test_reactor()
+        self.master = fakemaster.make_master(self, wantDb=True)
+        self.db = self.master.db
+        self.db.checkForeignKeys = True
+        self.insert_test_data = self.db.insert_test_data
+
+        return defer.succeed(None)
