@@ -21,12 +21,12 @@ import time
 from twisted.internet import defer
 from twisted.internet import reactor
 from twisted.internet.error import ProcessExitedAlready
+from twisted.logger import Logger
 from twisted.python.failure import Failure
 
 from buildbot import config
 from buildbot.util import asyncSleep
 from buildbot.util.httpclientservice import HTTPClientService
-from buildbot.util.logger import Logger
 from buildbot.util.protocol import LineProcessProtocol
 from buildbot.util.service import BuildbotService
 
@@ -76,7 +76,7 @@ class KubeHardcodedConfig(KubeConfigLoaderBase):
         if headers is not None:
             self.config['headers'] = headers
         if basicAuth and bearerToken:
-            raise Exception("set one of basicAuth and bearerToken, not both")
+            raise RuntimeError("set one of basicAuth and bearerToken, not both")
         self.basicAuth = basicAuth
         self.bearerToken = bearerToken
         if cert is not None:
@@ -155,7 +155,8 @@ class KubeCtlProxyConfigLoader(KubeConfigLoaderBase):
             self.pp,
             self.kube_ctl_proxy_cmd[0],
             self.kube_ctl_proxy_cmd + ["-p", str(self.proxy_port)],
-            env=None)
+            env=os.environ
+        )
         self.kube_proxy_output = yield self.pp.got_output_deferred
 
     def stopService(self):
@@ -256,7 +257,7 @@ class KubeClientService(HTTPClientService):
         url = f'/api/v1/namespaces/{namespace}/pods/{name}/status'
         while True:
             if time.time() - t1 > timeout:
-                raise TimeoutError("Did not see pod {name} terminate after {timeout}s")
+                raise TimeoutError(f"Did not see pod {name} terminate after {timeout}s")
             res = yield self.get(url)
             res_json = yield res.json()
             if res.code == 404:
