@@ -121,7 +121,7 @@ class Connection(base.Connection):
 
     def loseConnection(self):
         self.stopKeepaliveTimer()
-        self.protocol.sendClose()
+        self.protocol.transport.abortConnection()
 
     # keepalive handling
 
@@ -297,7 +297,9 @@ class Connection(base.Connection):
             del args['dir']
 
         if commandName == "rmfile":
-            args['path'] = self.path_module.join(self.builder_basedirs[builderName], args['path'])
+            args['path'] = self.path_module.join(self.builder_basedirs[builderName],
+                                                 self.path_expanduser(args['path'],
+                                                                      self.info['environ']))
 
         if commandName == "shell":
             args['workdir'] = self.path_module.join(self.builder_basedirs[builderName],
